@@ -18,6 +18,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <tqlayout.h>
 #include <tqtextbrowser.h>
 #include <tqstring.h>
